use std::collections::HashMap;

use lazy_regex::regex_captures;

use crate::http;

/// HTTP request line
///
/// `<method> <target> HTTP/<version>`
#[derive(Debug)]
pub struct RequestLine<'a> {
    pub method: &'a str,
    pub target: &'a str,
    pub version: http::Version,
}

impl RequestLine<'_> {
    pub(crate) fn from_str(str: &str) -> RequestLine<'_> {
        let (_, method, target, version) =
            regex_captures!(r#"([^\s]+)\s+([^\s]+)\s+HTTP\/([0-9.]+)"#, str).unwrap();

        RequestLine {
            method,
            target,
            version: http::Version::from_str(version),
        }
    }
}

#[derive(Debug)]
pub struct Request<'a> {
    pub request_line: RequestLine<'a>,
    pub headers: HashMap<&'a str, &'a str>,
}
