use std::collections::HashMap;

use crate::http;

#[derive(Debug)]
pub enum Status {
    OK,
    NotFound,
}

impl Status {
    fn code(&self) -> u16 {
        match self {
            Status::OK => 200,
            Status::NotFound => 404,
        }
    }

    fn message(&self) -> &str {
        match self {
            Status::OK => "OK",
            Status::NotFound => "Not Found",
        }
    }

    pub(crate) fn to_string(&self) -> String {
        format!("{} {}", self.code(), self.message())
    }
}

/// HTTP response line
///
/// `HTTP/<version> <status-code> <status-message>`
#[derive(Debug)]
pub struct ResponseLine {
    pub version: http::Version,
    pub status: Status,
}

impl ResponseLine {
    pub fn new(version: http::Version, status: Status) -> Self {
        ResponseLine { version, status }
    }

    pub(crate) fn to_string(&self) -> String {
        format!("HTTP/{} {}", self.version.to_str(), self.status.to_string())
    }
}

#[derive(Debug)]
pub struct Response<'a> {
    pub response_line: ResponseLine,
    pub headers: Option<HashMap<&'a str, &'a str>>,
    pub content: Option<Vec<u8>>,
}
